Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(578)

Unified Diff: src/ic/ic-inl.h

Issue 894683003: Introduce LanguageMode, drop StrictMode. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: rebased (w/ conflicts) Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ic/ic-compiler.cc ('k') | src/ic/x64/ic-compiler-x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ic/ic-inl.h
diff --git a/src/ic/ic-inl.h b/src/ic/ic-inl.h
index 58d7d4608f7b3ec8c2d3a5980e777b6b0ef4b684..484b3a564cb7216e446d099940de1a33df198e0a 100644
--- a/src/ic/ic-inl.h
+++ b/src/ic/ic-inl.h
@@ -106,11 +106,11 @@ void IC::SetTargetAtAddress(Address address, Code* target,
Code* old_target = GetTargetAtAddress(address, constant_pool);
#ifdef DEBUG
// STORE_IC and KEYED_STORE_IC use Code::extra_ic_state() to mark
// ICs as strict mode. The strict-ness of the IC must be preserved.
if (old_target->kind() == Code::STORE_IC ||
old_target->kind() == Code::KEYED_STORE_IC) {
- DCHECK(StoreIC::GetStrictMode(old_target->extra_ic_state()) ==
- StoreIC::GetStrictMode(target->extra_ic_state()));
+ DCHECK(StoreIC::GetLanguageMode(old_target->extra_ic_state()) ==
+ StoreIC::GetLanguageMode(target->extra_ic_state()));
}
#endif
Assembler::set_target_address_at(address, constant_pool,
@@ -140,16 +140,16 @@ void LoadIC::set_target(Code* code) {
void StoreIC::set_target(Code* code) {
- // Strict mode must be preserved across IC patching.
- DCHECK(GetStrictMode(code->extra_ic_state()) ==
- GetStrictMode(target()->extra_ic_state()));
+ // Language mode must be preserved across IC patching.
+ DCHECK(GetLanguageMode(code->extra_ic_state()) ==
+ GetLanguageMode(target()->extra_ic_state()));
IC::set_target(code);
}
void KeyedStoreIC::set_target(Code* code) {
- // Strict mode must be preserved across IC patching.
- DCHECK(GetStrictMode(code->extra_ic_state()) == strict_mode());
+ // Language mode must be preserved across IC patching.
+ DCHECK(GetLanguageMode(code->extra_ic_state()) == language_mode());
IC::set_target(code);
}
« no previous file with comments | « src/ic/ic-compiler.cc ('k') | src/ic/x64/ic-compiler-x64.cc » ('j') | no next file with comments »
@@ -106,11 +106,11 @@ void IC::SetTargetAtAddress(Address address, Code* target,
#ifdef DEBUG
// STORE_IC and KEYED_STORE_IC use Code::extra_ic_state() to mark
- // ICs as strict mode. The strict-ness of the IC must be preserved.
+ // ICs as language mode. The language mode of the IC must be preserved.
if (old_target->kind() == Code::STORE_IC ||
old_target->kind() == Code::KEYED_STORE_IC) {

Powered by Google App Engine
This is Rietveld 408576698